@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2006 the xine project
+ * Copyright (C) 2000-2017 the xine project
  *
  * This file is part of xine, a free video player.
  *
@@ -45,14 +45,12 @@
 extern "C" {
 #endif
 
-#include <sys/types.h>
-#include <sys/time.h>
-#include <time.h>
 #include <stdarg.h>
+#include <sys/time.h>
+#include <sys/types.h>
 
-#ifdef WIN32
+#if defined(WIN32) && !defined(XINE_COMPILE)
 #include <windows.h>
-#include <windowsx.h>
 #endif
 
 #include <xine/os_types.h>
@@ -230,6 +228,35 @@ int xine_stream_master_slave(xine_stream_t *master, xine_stream_t *slave,
  */
 int xine_open (xine_stream_t *stream, const char *mrl) XINE_PROTECTED;
 
+/** The keyframe seek index feature. */
+
+#define XINE_KEYFRAMES 1 /**<< Check this for feature available. */
+
+typedef struct {
+  int msecs;   /**<< Milliseconds from beginning of stream. */
+  int normpos; /**<< Size based stream position (beginning == 0, end == 64k - 1). */
+} xine_keyframes_entry_t;
+
+/** @brief Query stream keyframe seek index.
+    @note  We dont do an expensive file scan. We will only find keyframes listed in
+           container or already seen while playing.
+    @param stream The stream that index is for.
+    @param pos    On call, the start time or normpos.
+                  On return, the found time and normpos.
+    @param offs   0 gets nearest keyframe, other values step from exact given pos.
+    @return  0: Found.
+             1: Search truncated to first or last known keyframe.
+             2: Failure.
+*/
+int xine_keyframes_find (xine_stream_t *stream, xine_keyframes_entry_t *pos, int offs) XINE_PROTECTED;
+
+/** @brief Get a private stream keyframe seek index copy, free () it when done.
+    @param stream The stream that index is for.
+    @param size   On return, the count of entries there are.
+    @return The entry array or NULL.
+*/
+xine_keyframes_entry_t *xine_keyframes_get (xine_stream_t *stream, int *size) XINE_PROTECTED;
+
 /*
  * play a stream from a given position
  *
@@ -355,6 +382,7 @@ int  xine_get_param (xine_stream_t *stream, int param) XINE_PROTECTED;
 #define XINE_PARAM_VO_CROP_RIGHT           0x01000021 /* crop frame pixels  */
 #define XINE_PARAM_VO_CROP_TOP             0x01000022 /* crop frame pixels  */
 #define XINE_PARAM_VO_CROP_BOTTOM          0x01000023 /* crop frame pixels  */
+#define XINE_PARAM_VO_SINGLE_STEP          0x01000024 /* 1 = "advance to next frame, then pause" */
 
 #define XINE_VO_ZOOM_STEP                  100
 #define XINE_VO_ZOOM_MAX                   400
@@ -1452,7 +1480,7 @@ typedef struct {
 
 } fb_visual_t;
 
-#ifdef WIN32
+#if defined(WIN32) && (!defined(XINE_COMPILE) || defined(XINE_NEED_WIN32_VISUAL))
 /*
  * this is the visual data struct any win32 gui should supply
  * (pass this to init_video_out_plugin or the xine_load_video_output_plugin
